import pandas as pd
import logging

logger = logging.getLogger()


def get_steps(sql_command: str, chunksize: int, connection, is_tablename: bool = False) -> int:
    final_steps = 0
    try:
        if is_tablename:
            count_command = f'SELECT COUNT(*) FROM {sql_command}'
        else:
            count_command = f"SELECT COUNT(*) FROM ({sql_command}) BCOM"
        with connection.connect() as conn:
            result = conn.execute(count_command).first()
            if result:
                total_rows = int(result[0])
        logger.info(f"Total de filas: {total_rows}")
        if total_rows == chunksize:
            final_steps = 1
        else:
            final_steps = int(total_rows/chunksize) + 1
    except Exception as e:
        logger.error(f"Error calculando el total de N° de filas desde el comando: {sql_command}. {e}")
    finally:
        return final_steps


def get_iterator(command: str, chunksize: int, connection) -> iter:
    iterator = None
    try:
        connection = connection.execution_options(stream_results=True)
        iterator = pd.read_sql(command, connection, index_col=None, chunksize=chunksize)
        iterator = iter(iterator)
    except Exception as e:
        logger.error(f"Error trayendo iterator. {e}")
    finally:
        return iterator

