
from airflow.providers.amazon.aws.sensors.s3 import S3KeySensor
from airflow.providers.google.cloud.hooks.gcs import GCSHook
from airflow.sensors.base import BaseSensorOperator

from enums.ProviderTypeEnum import ProviderTypeEnum

import logging

logger = logging.getLogger()

POKE_INTERVAL = 5
TIMEOUT = 60*1
VERIFY_SSL = False


def create_sensor(task_id: str, connection: str, bucket: str, key: str, provider: str = "google"):
    sensor = None
    try:
        if provider == ProviderTypeEnum.GOOGLE.value:
            sensor = GCPSensor(
                task_id=task_id,
                conn=connection,
                bucket=bucket,
                key=key,
                poke_interval=POKE_INTERVAL,
                timeout=TIMEOUT
            )
        else:
            sensor = S3KeySensor(
                task_id=task_id,
                bucket_key=key,
                bucket_name=bucket,
                wildcard_match=True,
                aws_conn_id=connection,
                verify=VERIFY_SSL,
                poke_interval=POKE_INTERVAL,
                timeout=TIMEOUT
            )
    except Exception as e:
        logger.error(f"Error creando Sensor S3. {e}")
    return sensor


class GCPSensor(BaseSensorOperator):

    def __init__(self, conn: str, bucket: str, key: str, **kwargs) -> None:
        self.conn = conn
        self.bucket = bucket
        self.key = key
        super().__init__(**kwargs)

    def poke(self, context):
        hook = GCSHook(self.conn)
        end_prefix_index = self.key.rfind("/")
        if end_prefix_index != -1 and len(self.key[end_prefix_index:]) > 1:
            self.key = self.key[:end_prefix_index + 1]
        files = hook.list(self.bucket, prefix=self.key)
        files = list(map(lambda x: not x.endswith("/"), files))
        return any([criteria for criteria in files])

